<?php

namespace Modules\Admin\Http\Controllers;

use App\Http\Controllers\Controller;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;
use Illuminate\Database\QueryException;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;

use App\Models\User;
use App\Models\AdminDetails;
use App\Models\CustomerDetails;

use File;
use Mail;
use Image;
use PDF;
class UserController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function login(Request $request)
    {
        if($request->isMethod('get')){
            return view('admin::user.login');
         }
         if($request->isMethod('post')){

            $request->validate([
                'email'   => 'required',
                'password'  => 'required'
            ]);

               $user_data = array(
                'email'  => $request->get('email'),
                'status'  => "active",
                'user_role'  => 1,
                'password' => $request->get('password')
               );

               if(Auth::attempt($user_data))
               {
                return redirect('admin/dashboard');
               }
               else
               {
                return back()->with('fail', 'Wrong Login Details');
               }
         }
    }
    public function dashboard()
    {
        return view('admin::dashboard.index');
    }
    public function add_admin(Request $request)
    { if($request->isMethod('get')){
        return view('admin::user.add_admin');
    }
    if($request->isMethod('post')){

        $request->validate([
            'name'   => 'required',
            'phone'   => 'required',
            'email'   => 'required | email | unique:users',
            "password" => "required | confirmed | min:6",
        ]);

           DB::beginTransaction();
           $user = User::create([
              "email" => $request->email,
              "password" => Hash::make($request->password),
              "user_role" => 1,
              "status" => "active"
           ]);

           $userDetails = new AdminDetails();
           $userDetails->user_id =$user->id;
           $userDetails->name = $request->name;
           $userDetails->phone = $request->phone;
           $userDetails->save();
           DB::commit();
            return back()->with('success', 'Admin Successfully Added');

    }

    }
    public function admins()
    {
        $admins = User::where('user_role','1')->get();
        return view('admin::user.admins',['admins' => $admins]);
    }
    public function deactivate_admin($id){
        $user = User::find($id);
        $user->status = "inactive";
        $user->update();
        return back()->with('success', 'Admin Deactivated');

    }
    public function activate_admin($id){
        $user = User::find($id);
        $user->status = "active";
        $user->update();
        return back()->with('success', 'Admin Activated');

    }

    public function edit_admin($id,Request $request)
    {
    if($request->isMethod('get')){
    $login_details = User::where('id',$id)->first();
    $other_details = AdminDetails::where('user_id',$id)->first();
    return view('admin::user.edit_admin', ['login_details' => $login_details,'other_details' => $other_details]);
    }
    if($request->isMethod('post')){
        $request->validate([
            'name'   => 'required',
            'phone'   => 'required',
            'email'   => 'required',
        ]);

    if(!$request->current_password == null || !$request->password == null || !$request->password_confirmation == null){
        $this->validate($request, [
            "password" => "required | confirmed | min:6",
            "current_password" => "required",
           ]);
           if (Hash::check($request->input('current_password'), User::where('id', $id)->value('password'))) {
            if(User::where("id", "=", $id)->where("email", "=", $request->email)->exists()){
                $email = $request->email;
            }
            elseif(User::where("email", "=", $request->email)->exists()){
             return back()->with('fail', 'This email is already in use');
            }
            else{
             $email = $request->email;
            }

            $userDetails =  AdminDetails::where('user_id', '=', $id)->first();;
            $userDetails->name = $request->name;
            $userDetails->phone = $request->phone;
            $userDetails->update();
            $user = User::find($id);
            $user->email = $email;
            $user->password = Hash::make($request->input('password'));
            $user->update();
            return back()->with('success', 'Admin Details Successfully  Updated');
           }
           else{
            return back()->with('fail', 'Current password is incorrect.');
        }
    }
    else{
        if(User::where("id", "=", $id)->where("email", "=", $request->email)->exists()){
            $email = $request->email;
        }
        elseif(User::where("email", "=", $request->email)->exists()){
         return back()->with('fail', 'This email is already in use');
        }
        else{
         $email = $request->email;
        }

        $userDetails =  AdminDetails::where('user_id', '=', $id)->first();;
        $userDetails->name = $request->name;
        $userDetails->phone = $request->phone;
        $userDetails->update();
        $user = User::find($id);
        $user->email = $email;
        $user->update();
        return back()->with('success', 'Admin Details Successfully  Updated');
    }


    }

    }

    public function delete_admin($id,Request $request)
    {
        User::find($id)->delete();
        AdminDetails::where('user_id', '=', $id)->delete();;
        return back()->with('success', 'Admin Deleted');
    }
 public function customers()
    {
        $customers = User::where('user_role','2')->with('customerDetails')->get();
        return view('admin::user.customers',['customers' => $customers]);
    }
    
    public function deactivate_customer($id){
        $user = User::find($id);
        $user->status = "inactive";
        $user->update();
        return back()->with('success', 'Customer Deactivated');

    }
    public function activate_customer($id){
        $user = User::find($id);
        $user->status = "active";
        $user->update();
        return back()->with('success', 'Customer Activated');

    }
    public function delete_customer($id,Request $request)
    {
        User::find($id)->delete();
        CustomerDetails::where('user_id', '=', $id)->delete();;
        return back()->with('success', 'Customer Deleted');
    }
    function logout()
    {
     Auth::logout();
     return redirect('admin');
    }
    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin::create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request): RedirectResponse
    {
        //
    }

    /**
     * Show the specified resource.
     */
    public function show($id)
    {
        return view('admin::show');
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit($id)
    {
        return view('admin::edit');
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, $id): RedirectResponse
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy($id)
    {
        //
    }
}
