<?php
use Illuminate\Support\ServiceProvider;
use Illuminate\Routing\Router;
use Illuminate\Support\Facades\Route;
use Modules\Admin\Http\Controllers\UserController;
use Modules\Admin\Http\Controllers\ProductController;
use Modules\Admin\Http\Controllers\GRNController;
use Modules\Admin\Http\Controllers\SalesController;
use Modules\Admin\Http\Middleware\AdminAuthenticated;
use Illuminate\Http\Request;
/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::prefix('admin')->group(function() {
    Route::get( '/logout', [UserController::class, 'logout']);
    Route::match(['get', 'post'],'/', [UserController::class, 'login']);
    Route::match(['get', 'post'],'/admins', [UserController::class, 'admins'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/dashboard', [UserController::class, 'dashboard'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/add-admin', [UserController::class, 'add_admin'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/edit-admin/{user_id}', [UserController::class, 'edit_admin'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/delete-admin/{user_id}', [UserController::class, 'delete_admin'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/deactivate-admin/{user_id}', [UserController::class, 'deactivate_admin'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/activate-admin/{user_id}', [UserController::class, 'activate_admin'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/customers', [UserController::class, 'customers'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/deactivate-customer/{user_id}', [UserController::class, 'deactivate_customer'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/activate-customer/{user_id}', [UserController::class, 'activate_customer'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/delete-customer/{user_id}', [UserController::class, 'delete_customer'])->middleware(AdminAuthenticated::class);

    Route::match(['get', 'post'],'/add-company', [ProductController::class, 'add_company'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/companies', [ProductController::class, 'companies'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/edit-company/{id}', [ProductController::class, 'edit_company'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/deactivate-company/{id}', [ProductController::class, 'deactivate_company'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/activate-company/{id}', [ProductController::class, 'activate_company'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/delete-company/{id}', [ProductController::class, 'delete_company'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/add-suplier', [ProductController::class, 'add_suplier'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/supliers', [ProductController::class, 'supliers'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/edit-suplier/{id}', [ProductController::class, 'edit_suplier'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/deactivate-suplier/{id}', [ProductController::class, 'deactivate_suplier'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/activate-suplier/{id}', [ProductController::class, 'activate_suplier'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/delete-suplier/{id}', [ProductController::class, 'delete_suplier'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/categories', [ProductController::class, 'categories'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/deactivate-category/{id}', [ProductController::class, 'deactivate_category'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/activate-category/{id}', [ProductController::class, 'activate_category'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/edit-category/{id}', [ProductController::class, 'edit_category'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/delete-category/{id}', [ProductController::class, 'delete_category'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/brands', [ProductController::class, 'brands'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/deactivate-brand/{id}', [ProductController::class, 'deactivate_brand'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/activate-brand/{id}', [ProductController::class, 'activate_brand'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/edit-brand/{id}', [ProductController::class, 'edit_brand'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/delete-brand/{id}', [ProductController::class, 'delete_brand'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/add-product', [ProductController::class, 'add_product'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/products', [ProductController::class, 'products'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/edit-product/{id}', [ProductController::class, 'edit_product'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/deactivate-product/{id}', [ProductController::class, 'deactivate_product'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/activate-product/{id}', [ProductController::class, 'activate_product'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/delete-product/{id}', [ProductController::class, 'delete_product'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/get-sub-categories/{id}', [ProductController::class, 'get_sub_categories'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/delete-gallery-image/{id}', [ProductController::class, 'delete_gallery_image'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/add-grn', [GRNController::class, 'add_grn'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/grns', [GRNController::class, 'grns'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/edit-grn/{id}', [GRNController::class, 'edit_grn'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/add-return', [GRNController::class, 'add_return'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/returns', [GRNController::class, 'returns'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/edit-return/{id}', [GRNController::class, 'edit_return'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/add-order', [SalesController::class, 'add_order'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/get-batches/{id}', [SalesController::class, 'get_batches'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/all-orders', [SalesController::class, 'all_orders'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/download-invoice/{id}', [SalesController::class, 'download_invoice'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/edit-order/{id}', [SalesController::class, 'edit_order'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/order-requests', [SalesController::class, 'order_requests'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/delete-order-request/{id}', [SalesController::class, 'delete_order_request'])->middleware(AdminAuthenticated::class);


    Route::match(['get', 'post'],'/mail-test', [SalesController::class, 'mail_test'])->middleware(AdminAuthenticated::class);

    Route::match(['get', 'post'],'/banners', [ProductController::class, 'banners'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/deactivate-banner/{id}', [ProductController::class, 'deactivate_banner'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/activate-banner/{id}', [ProductController::class, 'activate_banner'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/delete-banner/{id}', [ProductController::class, 'delete_banner'])->middleware(AdminAuthenticated::class);
    Route::match(['get', 'post'],'/edit-banner/{id}', [ProductController::class, 'edit_banner'])->middleware(AdminAuthenticated::class);
});


