<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\Models\CustomerDetails;
use App\Models\Products;
use App\Models\OrderRequests;

class APIController extends Controller
{


public function register(Request $request){

    $request->validate([
        'customer_name'   => 'required',
        'customer_type'   => 'required',
        'phone'   => 'required',
        'email'   => 'required|email|unique:users,email',
        'address'   => 'required',
        'password' => 'required|min:6|confirmed',
    ]);

    DB::beginTransaction();
    
    try {

        $user = User::create([
            "email" => $request->email,
            "password" => Hash::make($request->password),
            "user_role" => 2,
            "status" => "inactive"
        ]);

        $userDetails = new CustomerDetails();
        $userDetails->user_id = $user->id;
        $userDetails->customer_name = $request->customer_name;
        $userDetails->customer_type = $request->customer_type;
        $userDetails->phone = $request->phone;
        $userDetails->address = $request->address;
        $userDetails->company_name = $request->company_name;
        $userDetails->vat_no = $request->vat_no;
        $userDetails->kvk_no = $request->kvk_no;
        $userDetails->country = $request->country;
        $userDetails->tax_id = $request->tax_id;
        $userDetails->payment_terms = $request->payment_terms;
        $userDetails->grade = $request->grade;
        $userDetails->discount = $request->discount;
        $userDetails->loyalty_info = $request->loyalty_info;
        $userDetails->notes = $request->notes;
        $userDetails->save();

        DB::commit();

        
        $OTP =  rand ( 0000 , 9999 );

        $user = User::where('email',$request->email)->first();
        $user->otp = $OTP;
        $user->update();

        $details  = [
            'otp' => $OTP,
        ];

        Mail::to($request->email)->send(new \App\Mail\ConfirmEmail($details));

        return response()->json([
            'status' => "success",
            'message' => 'User registered successfully, Plese confirm your email to login.',
            'otp-sent-to' => $request->email,
        ], 201);

    } catch (\Exception $e) {
        DB::rollBack();

        return response()->json([
            'success' => false,
            'message' => 'User registration failed',
            'error' => $e->getMessage()
        ], 500);
    }
}
public function validate_otp(Request $request){

         if($request->otp == User::where('email',$request->email)->value('otp')){

                $user = User::where('email',$request->email)->first();
                $user->status = "active";
                $user->otp = null;
                $user->update();
                return redirect('/')->with('success', 'Email confirmation successful. Please login');

         }
         else{
            return back()->with('fail', 'You have entered the wrong OTP. Please try again');
         }
     
}
public function products()
{
    $products = Products::with('gallery')->get();
    return response()->json($products);
    
}

public function login(Request $request)
    {
            $request->validate([
                'email'   => 'required',
                'password'  => 'required'
            ]);

        $user_data = array(
        'email'  => $request->get('email'),
        'status'  => "active",
        'user_role'  => 1,
        'password' => $request->get('password')
        );

        if(Auth::attempt($user_data))
        {
        return json_encode(array("status"=> "success"));
        }
        else
        {
        return json_encode(array("status"=> "fail"));
        }
    }
    public function order_request(Request $request){

        $request->validate([
            'customer_id'   => 'required',
            'products'   => 'required',
        ]);
    
        
        try {
    
            $order_request = new OrderRequests();
            $order_request->customer_id = $request->customer_id;
            $order_request->products = $request->products;
            $order_request->save();

            $customer_email = User::where('id', $order_request->customer_id)->value('email');
            $details  = [
                'order_request' => $order_request,
            ];
            Mail::to($customer_email)->send(new \App\Mail\OrderConfirmation($details));
           
            return response()->json([
                'status' => "success",
                'message' => 'Order request saved',
                'order_request' => $order_request
            ]);

        } catch (\Exception $e) {
            return $e;
        }
    }
}
