<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\Models\CustomerDetails;
use App\Models\Products;
use App\Models\User;
use App\Models\OrderRequests;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\ValidationException;

class APIController extends Controller
{


public function register(Request $request)
{
    $validator = Validator::make($request->all(), [
        'customer_name' => 'required',
        'customer_type' => 'required',
        'phone' => 'required',
        'email' => 'required|email|unique:users,email',
        'address' => 'required',
        'password' => 'required|min:6',
    ]);


    if ($validator->fails()) {
        return response()->json([
             'status' => "fail",
            'message' => 'Validation errors',
            'errors' => $validator->errors()
        ], 422); 
    }

    DB::beginTransaction();
    try {
        $user = User::create([
            "email" => $request->email,
            "password" => Hash::make($request->password),
            "user_role" => 2,
            "status" => "active"
        ]);

        $userDetails = new CustomerDetails();
        $userDetails->user_id = $user->id;
        $userDetails->customer_name = $request->customer_name;
        $userDetails->customer_type = $request->customer_type;
        $userDetails->phone = $request->phone;
        $userDetails->address = $request->address;
        $userDetails->company_name = $request->company_name;
        $userDetails->vat_no = $request->vat_no;
        $userDetails->kvk_no = $request->kvk_no;
        $userDetails->country = $request->country;
        $userDetails->tax_id = $request->tax_id;
        $userDetails->payment_terms = $request->payment_terms;
        $userDetails->grade = $request->grade;
        $userDetails->discount = $request->discount;
        $userDetails->loyalty_info = $request->loyalty_info;
        $userDetails->notes = $request->notes;
        $userDetails->save();

        DB::commit();

        $OTP =  rand ( 0000 , 9999 );

        $user = User::where('email',$request->email)->first();
        $user->otp = $OTP;
        $user->update();

        $details  = [
            'otp' => $OTP,
        ];

        Mail::to($request->email)->send(new \App\Mail\ConfirmEmail($details));


        return response()->json([
            'status' => "success",
            'message' => 'User registered successfully',
            'user' => $user,
            'userDetails' => $userDetails
        ], 201);

    } catch (\Exception $e) {
        DB::rollBack();

        return response()->json([
            'status' => "fail",
            'message' => 'User registration failed',
            'error' => $e->getMessage()
        ], 500);
    }
}
public function validate_otp(Request $request){

    if($request->otp == User::where('email',$request->email)->value('otp')){

           $user = User::where('email',$request->email)->first();
           $user->status = "active";
           $user->otp = null;
           $user->update();

           $userDetails = CustomerDetails::where('user_id',$user->id)->first();

           return response()->json([
            'status' => "success",
            'message' => 'OTP is correct',
            'user' => $user,
            'userDetails' => $userDetails
        ], 201);

    }
    else{
        return response()->json([
            'status' => "fail",
            'message' => 'OTP is wrong',
        ], 500);
    }

}
public function products()
{
    $products = Products::with('gallery')->get();
    return response()->json($products);
    
}

public function login(Request $request)
    {
    $validator = Validator::make($request->all(), [
        'email' => 'required|email',
        'password' => 'required',
    ]);
    
     if ($validator->fails()) {
        return response()->json([
            'success' => false,
            'message' => 'Validation errors',
            'errors' => $validator->errors()
        ], 422); 
    }

    if(User::where("email", $request->email)->where("status", "active")->where("user_role", 2)->exists()){
        $user = User::where("email", $request->email)->where("status", "active")->where("user_role", 2)->with('customerDetails')->first();
        if (Hash::check($request->password, $user->password)) {
            return response()->json([
                'status' => "success",
                'message' => 'User login successful',
                'user' => $user,
            ], 201);
        }
        else{
            return response()->json([
            'status' => "fail",
            'message' => 'User login failed',
        ], 500);
        }
    }
    else{
        return response()->json([
            'status' => "fail",
            'message' => 'User login failed',
        ], 500);
    }

    }
    public function order_request(Request $request){


        $validator = Validator::make($request->all(), [
            'customer_id' => 'required',
            'products' => 'required',
        ]);
        
         if ($validator->fails()) {
            return response()->json([
                'success' => false,
                'message' => 'Validation errors',
                'errors' => $validator->errors()
            ], 422); 
        }       
        
        try {
            if(User::where("id", $request->customer_id)->where("status", "active")->where("user_role", 2)->exists()){
            $order_request = new OrderRequests();
            $order_request->customer_id = $request->customer_id;
            $order_request->products = $request->products;
            $order_request->save();
    
            return response()->json([
                'status' => "success",
                'message' => 'Order request saved',
                'order_request' => $order_request
            ]);
            }
            else{
                return response()->json([
                    'status' => "fail",
                    'message' => 'Customer does not exists',
                ], 500);
            }

        } catch (\Exception $e) {
             return response()->json([
                'status' => "fail",
                'message' => 'Order request failed',
                'error' => $e->getMessage()
            ], 500);
        }
    }
}
